@@ -4,15 +4,17 @@
 #'
 #' @param model \code{\linkS4class{SDMmodel}} or
 #' \code{\linkS4class{SDMmodelCV}} objects.
-#' @param test \code{\linkS4class{SWD}} test object for
-#' \code{\linkS4class{SDMmodel}} objects or logical for
+#' @param test \code{\linkS4class{SWD}} object for \code{\linkS4class{SDMmodel}}
+#' object. Logical or \code{\linkS4class{SWD}} object for
 #' \code{\linkS4class{SDMmodelCV}} objects, if not provided it computes the
-#' train AUC, default is \code{NULL}.
+#' train AUC, see details. Default is \code{NULL}.
 #' @param a Deprecated.
 #'
-#' @details If the model is a \code{\linkS4class{SDMmodelCV}} object, the
-#' function computes the mean of the training or testing AUC values of the
-#' different replicates.
+#' @details For \code{\linkS4class{SDMmodelCV}} objects, the function computes
+#' the mean of the training AUC values of the k-folds. If \code{test = TRUE} it
+#' computes the mean of the testing AUC values for the k-folds. If test is an
+#' \code{\linkS4class{SWD}} object, it computes the mean AUC values for the
+#' provided testing dataset.
 #'
 #' @return The value of the AUC.
 #' @export
@@ -64,6 +66,9 @@
 #'
 #' # Compute the testing AUC
 #' auc(model, test = TRUE)
+#'
+#' # Compute the AUC for the held apart testing dataset
+#' auc(model, test = test)
 #' }
 auc <- function(model, test = NULL, a = NULL) {
 
@@ -82,8 +87,7 @@ auc <- function(model, test = NULL, a = NULL) {
         if (isTRUE(test)) {
           test_swd <- .subset_swd(model@data, model@folds$test[, i])
         } else {
-          stop("\"test\" argument invalid for \"SDMmodelCV\" objects! Use ",
-               "TRUE or FALSE.")
+          test_swd <- test
         }
       } else {
         test_swd = NULL
@@ -109,6 +113,8 @@ auc <- function(model, test = NULL, a = NULL) {
     data <- model@data
   } else {
     # TODO check if can be removed: test@data[colnames(model@p@data)]
+    if (class(test) != "SWD")
+      stop("\"test\" argument invalid, use an SWD object.")
     data <- test
   }
 
